@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint;
-$HTML::FormFu::Constraint::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.02'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Processor';
@@ -14,7 +17,6 @@ use Clone ();
 use List::MoreUtils qw( any );
 use Scalar::Util qw( blessed );
 use Carp qw( croak );
-use Clone ();
 use List::MoreUtils qw( any all );
 use List::Util qw( first );
 use Scalar::Util qw( reftype blessed );
@@ -239,6 +241,7 @@ sub _process_when {
 
     # Callback will be the preferred thing
     if ($when_callback) {
+        ## no critic (ProhibitNoStrict);
         no strict 'refs';
         return $when_callback->( $params, $self );
     }
@@ -350,6 +353,10 @@ __END__
 
 HTML::FormFu::Constraint - Constrain User Input
 
+=head1 VERSION
+
+version 2.02
+
 =head1 SYNOPSIS
 
     ---
@@ -546,11 +553,11 @@ C<$constraint> (the Constraint object)
 
 Return value: $string
 
-Attempt to return the error message that would be used if this constraint 
+Attempt to return the error message that would be used if this constraint
 generated an error.
 
 This will generally be correct for simple constraints with a fixed message or
-which use a placeholder from a known value, such as 
+which use a placeholder from a known value, such as
 L<HTML::FormFu::Constraint::Min/min>.
 This will generally C<not> return the correct message for constraints which
 use L<HTML::FormFu::Role::Constraint::Others/others>, where the field with an
