@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Set;
-$HTML::FormFu::Constraint::Set::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.02'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -42,6 +45,10 @@ __END__
 
 HTML::FormFu::Constraint::Set - Set of Values Constraint
 
+=head1 VERSION
+
+version 2.02
+
 =head1 SYNOPSIS
 
     type: Set
